@@ -1,7 +1,4 @@
 #!/usr/bin/env python3
-import sys
-import os
-
 from jdMinecraftLauncher.jdMinecraftLauncher import main
 main()
 
