@@ -1,7 +1,7 @@
 import minecraft_launcher_lib
 import subprocess
 
-def runMinecraft(profile,env):
+def runMinecraft(profile,env,natives_path):
     versiontype, versionid = profile.getVersion().split(" ")
     options = {
         "username": env.account["name"],
@@ -11,6 +11,8 @@ def runMinecraft(profile,env):
         "launcherVersion": env.launcherVersion,
         "gameDirectory": profile.getGameDirectoryPath(),
     }
+    if profile.customExecutable:
+        options["executablePath"] = profile.executable
     if profile.customArguments:
         options["jvmArguments"] = []
         for i in profile.arguments.split(" "):
@@ -25,6 +27,9 @@ def runMinecraft(profile,env):
             options["port"] = profile.serverPort
     if profile.demoMode:
         options["demo"] = True
+    if natives_path != "":
+        options["nativesDirectory"] = natives_path
+        minecraft_launcher_lib.natives.extract_natives(versionid,env.dataPath,natives_path)
     command = minecraft_launcher_lib.command.get_minecraft_command(versionid,env.dataPath,options)
-    command = command[1:]
+    #command = command[1:]
     return command
